aboutsummaryrefslogtreecommitdiffstats
path: root/resources/libraries/python/autogen/Testcase.py
diff options
context:
space:
mode:
authorVratko Polak <vrpolak@cisco.com>2019-04-04 13:45:11 +0200
committerVratko Polak <vrpolak@cisco.com>2019-04-08 16:34:10 +0200
commit5e6145a4260ffce1c302e94b9b241851f90838e1 (patch)
tree2480a5419cf127ac64262d271b8094f4834b2a66 /resources/libraries/python/autogen/Testcase.py
parent5221220aa5a893e93d78ba31f84b0ad4d6245ec3 (diff)
Upgrade autogen to NICs and search types
+ All perf suites updated, as autogen change is backward incompatible. + Only x710 -ndrpdr suites remain in git repository. + Removed retry feature of run_tests. + Renamed topology_type and traffic_type to traffic_profile. + Renamed framesize to frame_size; nic_model to nic_name. + Reordered Variables table to start with nic_name and overhead. + Fixed wrong overhead value in some cbc-sha1 suites. + Fixed some suite tags. ++ Introduced tags to distinguish suites, such as IPSECINT. + Bound crypto hardware to NIC name. + Implemented NIC limit hiding. + Also search and teardown related arguments are now hidden. + Main measurement keywords updated to new arg handling. + Max rate related keywords moved to performance_limits.robot + Teardowns unified. + Generated tests are archived. ++ Generated directory is .gitignore-d. + Regenerator raises an exception on seeing non-compatible suite. ++ Relatively helpful message should be seen in exception. + Suite and template Documentation has generated parts. +- With short NIC names only. + Autogen checker also upgraded. + Tag expressions replaced with long files to ensure analogous tests. Change-Id: I60e9a999187e7da1f60d0eb4fb02afa14682aa46 Signed-off-by: Vratko Polak <vrpolak@cisco.com>
Diffstat (limited to 'resources/libraries/python/autogen/Testcase.py')
-rw-r--r--resources/libraries/python/autogen/Testcase.py10
1 files changed, 5 insertions, 5 deletions
diff --git a/resources/libraries/python/autogen/Testcase.py b/resources/libraries/python/autogen/Testcase.py
index dd58547f33..7d0a29b0ad 100644
--- a/resources/libraries/python/autogen/Testcase.py
+++ b/resources/libraries/python/autogen/Testcase.py
@@ -34,29 +34,29 @@ class Testcase(object):
"""
self.template = Template(template_string)
- def generate(self, num, framesize, phy_cores):
+ def generate(self, num, frame_size, phy_cores):
"""Return string of test case code with placeholders filled.
Fail if there are placeholders left unfilled.
:param num: Test case number. Example value: 4.
:param framesize: Imix string or numeric frame size. Example: 74.
:param phy_cores: Number of physical cores to use. Example: 2.
:type num: int
- :type framesize: str or int
+ :type frame_size: str or int
:type phy_cores: int or str
:returns: Filled template, usable as test case code.
:rtype: str
"""
try:
- fsize = int(framesize)
+ fsize = int(frame_size)
subst_dict = {
"frame_num": "${%d}" % fsize,
"frame_str": "%dB" % fsize
}
except ValueError: # Assuming an IMIX string.
subst_dict = {
- "frame_num": str(framesize),
+ "frame_num": str(frame_size),
"frame_str": "IMIX"
}
cores_str = str(phy_cores)
@@ -34,29 +34,29 @@ class Testcase(object):
Fail if there are placeholders left unfilled.
:param num: Test case number. Example value: 4.
- :param framesize: Imix string or numeric frame size. Example: 74.
+ :param frame_size: Imix string or numeric frame size. Example: 74.
:param phy_cores: Number of physical cores to use. Example: 2.
:type num: int